@@ -24,7 +24,7 @@
 #'   - `prop`: Proportion of subjects with AE.
 #'   - `total`: Total columns.
 #'   - `diff`: Risk difference.
-#' @param digits A value of digits to be displayed for proportion and
+#' @param digits A number of digits after decimal point to be displayed for proportion and
 #'   risk difference.
 #' @param width_term Width in px for AE term column.
 #' @param width_fig Width in px for proportion and risk difference figure.
@@ -32,9 +32,17 @@
 #' @param width_prop Width in px for "(%)" columns.
 #' @param width_diff Width in px for risk difference columns.
 #' @param footer_space Space in px for footer to display legend.
+#' @param prop_range A vector of lower and upper limit of x-axis
+#'   for proportion figure.
+#' @param diff_range A vector of lower and upper limit of x-axis
+#'   for risk difference figure.
 #' @param color A vector of colors for analysis groups.
 #'   Default value supports up to 4 groups.
 #' @param diff_label x-axis label for risk difference.
+#' @param col_header Column header for risk difference table columns.
+#'   If NULL (default), uses "Risk Difference (%) <br> vs. Reference Group".
+#' @param fig_header Column header for risk difference figure.
+#'   If NULL (default), uses "Risk Difference (%) + 95% CI <br> vs. Reference Group".
 #' @param show_ae_parameter A boolean value to display AE parameter column.
 #'
 #' @return An `outdata` object.
@@ -42,13 +50,13 @@
 #' @export
 #'
 #' @examples
-#' adsl <- forestly_adsl[1:100,]
-#' adae <- forestly_adae[1:100,]
+#' adsl <- forestly_adsl[1:100, ]
+#' adae <- forestly_adae[1:100, ]
 #' meta_forestly(
 #'   dataset_adsl = adsl,
 #'   dataset_adae = adae
 #' ) |>
-#'   prepare_ae_forestly()|>
+#'   prepare_ae_forestly() |>
 #'   format_ae_forestly()
 format_ae_forestly <- function(
     outdata,
@@ -60,8 +68,12 @@ format_ae_forestly <- function(
     width_prop = 60,
     width_diff = 80,
     footer_space = 90,
+    prop_range = NULL,
+    diff_range = NULL,
     color = NULL,
     diff_label = "Treatment <- Favor -> Placebo",
+    col_header = NULL,
+    fig_header = NULL,
     show_ae_parameter = FALSE) {
   display <- tolower(display)
 
@@ -71,6 +83,8 @@ format_ae_forestly <- function(
     several.ok = TRUE
   )
 
+  display_n <- "n" %in% display
+  display_prop <- "prop" %in% display
   display_total <- "total" %in% display
   display_diff <- "diff" %in% display
 
@@ -87,6 +101,18 @@ format_ae_forestly <- function(
   name_n <- names(outdata$n)[1:m_group]
   name_prop <- names(outdata$prop)[1:m_group]
 
+  # Get reference group name for headers
+  reference_name <- outdata$group[index_reference]
+
+  # Set default headers if not provided
+  if (is.null(col_header)) {
+    col_header <- paste0("Risk Difference (%) <br> vs. ", reference_name)
+  }
+
+  if (is.null(fig_header)) {
+    fig_header <- paste0("Risk Difference (%) + 95% CI <br> vs. ", reference_name)
+  }
+
   # Input checking
   if (is.null(color)) {
     if (n_group <= 2) {
@@ -125,10 +151,18 @@ format_ae_forestly <- function(
   tbl_prop <- outdata$prop[, 1:n_group]
   y <- rep(NA, n_group)
   y[outdata$reference_group] <- mean(1:n_group1)
-  y[-outdata$reference_group] <- 1:n_group1
+  y[-outdata$reference_group] <- rev(1:n_group1)
 
   # Calculate the range of the forest plot
-  fig_prop_range <- round(range(tbl_prop, na.rm = TRUE) + c(-2, 2))
+  if (is.null(prop_range)) {
+    fig_prop_range <- round(range(tbl_prop, na.rm = TRUE) + c(-2, 2))
+  } else {
+    if (prop_range[1] > range(tbl_prop, na.rm = TRUE)[1] |
+      prop_range[2] < range(tbl_prop, na.rm = TRUE)[2]) {
+      warning("There are data points outside the specified range for proportion.")
+    }
+    fig_prop_range <- prop_range
+  }
   fig_prop_color <- color[1:n_group]
 
   # Function to create proportion of subjects figure
@@ -166,7 +200,15 @@ format_ae_forestly <- function(
 
   # Function to create proportion difference figure
   tbl_diff <- data.frame(outdata$diff, outdata$ci_lower, outdata$ci_upper)
-  fig_diff_range <- round(range(tbl_diff, na.rm = TRUE) + c(-2, 2))
+  if (is.null(diff_range)) {
+    fig_diff_range <- round(range(tbl_diff, na.rm = TRUE) + c(-2, 2))
+  } else {
+    if (diff_range[1] > range(tbl_diff, na.rm = TRUE)[1] |
+      diff_range[2] < range(tbl_diff, na.rm = TRUE)[2]) {
+      warning("There are data points outside the specified range for difference.")
+    }
+    fig_diff_range <- diff_range
+  }
   fig_diff_color <- fig_prop_color[index_diff]
 
   iter <- 1:ncol(outdata$diff) - 1
@@ -177,7 +219,7 @@ format_ae_forestly <- function(
     x = names(outdata$diff),
     x_lower = names(outdata$ci_lower),
     x_upper = names(outdata$ci_upper),
-    y = 1:ncol(outdata$diff),
+    y = rev(1:ncol(outdata$diff)),
     xlim = fig_diff_range,
     color = fig_diff_color,
     width = width_fig,
@@ -209,7 +251,7 @@ format_ae_forestly <- function(
     )
   }
   columnGroups[[m_group + 1]] <- reactable::colGroup(
-    name = "Risk Difference (%) <br> vs. Placebo",
+    name = col_header,
     html = TRUE,
     columns = names(outdata$diff)
   )
@@ -237,7 +279,8 @@ format_ae_forestly <- function(
   col_n <- lapply(name_n, function(x) {
     reactable::colDef(
       header = "n", defaultSortOrder = "desc",
-      minWidth = width_n, align = "center"
+      minWidth = width_n, align = "center",
+      show = display_n
     )
   })
   names(col_n) <- name_n
@@ -247,9 +290,10 @@ format_ae_forestly <- function(
     reactable::colDef(
       header = "(%)", defaultSortOrder = "desc",
       minWidth = width_prop, align = "center",
+      show = display_prop,
       format = reactable::colFormat(
         prefix = "(",
-        digits = 1,
+        digits = digits,
         suffix = ")"
       )
     )
@@ -266,7 +310,7 @@ format_ae_forestly <- function(
         header = outdata$group[i],
         minWidth = width_diff,
         show = display_diff,
-        format = reactable::colFormat(digits = 1)
+        format = reactable::colFormat(digits = digits)
       )
     }
   )
@@ -287,6 +331,8 @@ format_ae_forestly <- function(
     header = "AE Proportion (%)",
     width = ifelse("fig_prop" %in% display, width_fig, 0),
     align = "center",
+    sortable = FALSE,
+    filterable = FALSE,
     cell = reactable::JS(js_prop_fig_cell),
     footer = reactable::JS(js_prop_fig_footer),
     html = TRUE,
@@ -296,10 +342,12 @@ format_ae_forestly <- function(
 
   # difference format
   col_diff_fig <- list(diff_fig = reactable::colDef(
-    header = "Risk Difference (%) + 95% CI <br> vs. Placebo",
+    header = fig_header,
     defaultSortOrder = "desc",
     width = ifelse("fig_diff" %in% display, width_fig, 0),
     align = "center",
+    sortable = FALSE,
+    filterable = FALSE,
     cell = reactable::JS(js_diff_fig_cell),
     footer = reactable::JS(js_diff_fig_footer),
     html = TRUE,
@@ -321,14 +369,16 @@ format_ae_forestly <- function(
   )
 
   # column hidden
-  columns <- lapply(columns, function (x) {
+  columns <- lapply(columns, function(x) {
     if (!"show" %in% names(x)) {
       x$show <- TRUE
     }
     return(x)
   })
 
-  hidden_item <- names(columns)[(!names(columns) %in% "soc_name") & (sapply(columns, function(x) {return(!x$show)}))]
+  hidden_item <- names(columns)[(!names(columns) %in% "soc_name") & (sapply(columns, function(x) {
+    return(!x$show)
+  }))]
 
   # Create outdata
   outdata$tbl <- tbl
